==> slurm-wlm_24.11.5.orig.tar.gz: slurm-slurm-24-11-5-1/src/curl/slurm_curl.h <==
/****************************************************************************\
 *  slurm_curl.h
 *****************************************************************************
 *  Copyright (C) SchedMD LLC.
 *
 *  This file is part of Slurm, a resource management program.
 *  For details, see <https://slurm.schedmd.com/>.
 *  Please also read the included file: DISCLAIMER.
 *
 *  Slurm is free software; you can redistribute it and/or modify it under
 *  the terms of the GNU General Public License as published by the Free
 *  Software Foundation; either version 2 of the License, or (at your option)
 *  any later version.
 *
 *  In addition, as a special exception, the copyright holders give permission
 *  to link the code of portions of this program with the OpenSSL library under
 *  certain conditions as described in each individual source file, and
 *  distribute linked combinations including the two. You must obey the GNU
 *  General Public License in all respects for all of the code used other than
 *  OpenSSL. If you modify file(s) with this exception, you may extend this
 *  exception to your version of the file(s), but you are not obligated to do
 *  so. If you do not wish to do so, delete this exception statement from your
 *  version.  If you delete this exception statement from all source files in
 *  the program, then also delete it here.
 *
 *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
 *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 *  details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with Slurm; if not, write to the Free Software Foundation, Inc.,
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
\****************************************************************************/

#ifndef _SLURM_CURL_H
#define _SLURM_CURL_H

#include "src/common/http.h"
#include <curl/curl.h>

extern int slurm_curl_request(const char *data, const char *url,
			      const char *username, const char *password,
			      struct curl_slist *headers, uint32_t timeout,
			      char **response_str, long *response_code,
			      http_request_method_t request_method,
			      bool verify_cert);

extern int slurm_curl_init(void);

extern int slurm_curl_fini(void);

#endif

==> slurm-wlm_25.05.4.orig.tar.gz: slurm-slurm-25-05-4-1/src/curl/slurm_curl.h <==
/****************************************************************************\
 *  slurm_curl.h
 *****************************************************************************
 *  Copyright (C) SchedMD LLC.
 *
 *  This file is part of Slurm, a resource management program.
 *  For details, see <https://slurm.schedmd.com/>.
 *  Please also read the included file: DISCLAIMER.
 *
 *  Slurm is free software; you can redistribute it and/or modify it under
 *  the terms of the GNU General Public License as published by the Free
 *  Software Foundation; either version 2 of the License, or (at your option)
 *  any later version.
 *
 *  In addition, as a special exception, the copyright holders give permission
 *  to link the code of portions of this program with the OpenSSL library under
 *  certain conditions as described in each individual source file, and
 *  distribute linked combinations including the two. You must obey the GNU
 *  General Public License in all respects for all of the code used other than
 *  OpenSSL. If you modify file(s) with this exception, you may extend this
 *  exception to your version of the file(s), but you are not obligated to do
 *  so. If you do not wish to do so, delete this exception statement from your
 *  version.  If you delete this exception statement from all source files in
 *  the program, then also delete it here.
 *
 *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
 *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 *  details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with Slurm; if not, write to the Free Software Foundation, Inc.,
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
\****************************************************************************/

#ifndef _SLURM_CURL_H
#define _SLURM_CURL_H

#include "src/common/http.h"
#include <curl/curl.h>

extern int slurm_curl_request(const char *data, const char *url,
			      const char *username, const char *password,
			      const char *mtls_ca_path,
			      const char *mtls_cert_path, char *mtls_key_path,
			      struct curl_slist *headers, uint32_t timeout,
			      char **response_str, long *response_code,
			      http_request_method_t request_method,
			      bool verify_cert, bool use_mtls);

extern int slurm_curl_init(void);

extern int slurm_curl_fini(void);

#endif
